[![Apache-2.0 License](https://img.shields.io/github/license/saltstack/salt)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI package](https://badge.fury.io/py/mlx.treemap.svg)](https://pypi.org/project/mlx.treemap/)
[![Build status](https://github.com/melexis/treemap/actions/workflows/python-package.yml/badge.svg?branch=main)](https://github.com/melexis/treemap/actions/workflows/python-package.yml)
[![Documentation](https://img.shields.io/badge/Documentation-published-brightgreen.svg)](https://melexis.github.io/treemap/)
[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/melexis/treemap/issues)

# Sphinx Plugin for Treemap Generation

Sphinx extension that generates a treemap from a Cobertura XML file.
